@@ -1,29 +1,31 @@
 # -*- coding: utf-8 -*-
+
+from django.utils.translation import ugettext as _
 from django.http import HttpResponse
 from django.template import loader
 from django.template.base import TemplateDoesNotExist, Template
 from django.template.context import RequestContext
+from concurrency.exceptions import RecordModifiedError
 
 
 class ConflictResponse(HttpResponse):
     status_code = 409
 
+
 handler409 = 'concurrency.views.conflict'
 
 
 def callback(target, *args, **kwargs):
-    pass
+    raise RecordModifiedError(_('Record has been modified'), target=target)
 
 
 def conflict(request, target=None, template_name='409.html'):
-    """
-    409 error handler.
+    """409 error handler.
 
     Templates: `409.html`
     Context:
     `target` : The model to save
-    `saved` : The object stored in the db that produce the
-               conflict or None if not found (ie. deleted)
+    `saved`  : The object stored in the db that produce the conflict or None if not found (ie. deleted)
     `request_path` : The path of the requested URL (e.g., '/app/pages/bad_page/')
 
     """
@@ -36,7 +38,7 @@ def conflict(request, target=None, template_name='409.html'):
             'The object changed during the transaction.</p>')
     try:
         saved = target.__class__._default_manager.get(pk=target.pk)
-    except target.__class__.DoesNotExists:
+    except target.__class__.DoesNotExist:
         saved = None
     ctx = RequestContext(request, {'target': target,
                                    'saved': saved,
